==> aws-java-sdk-waf-1.10.60-sources.jar: com/amazonaws/services/waf/model/transform/SqlInjectionMatchSetUpdateJsonUnmarshaller.java <==
/*
 * Copyright 2010-2016 Amazon.com, Inc. or its affiliates. All Rights
 * Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.waf.model.transform;

import java.util.Map;
import java.util.Map.Entry;

import com.amazonaws.services.waf.model.*;
import com.amazonaws.transform.SimpleTypeJsonUnmarshallers.*;
import com.amazonaws.transform.*;

import com.fasterxml.jackson.core.JsonToken;
import static com.fasterxml.jackson.core.JsonToken.*;

/**
 * SqlInjectionMatchSetUpdate JSON Unmarshaller
 */
public class SqlInjectionMatchSetUpdateJsonUnmarshaller implements
        Unmarshaller<SqlInjectionMatchSetUpdate, JsonUnmarshallerContext> {

    public SqlInjectionMatchSetUpdate unmarshall(JsonUnmarshallerContext context)
            throws Exception {
        SqlInjectionMatchSetUpdate sqlInjectionMatchSetUpdate = new SqlInjectionMatchSetUpdate();

        int originalDepth = context.getCurrentDepth();
        String currentParentElement = context.getCurrentParentElement();
        int targetDepth = originalDepth + 1;

        JsonToken token = context.getCurrentToken();
        if (token == null)
            token = context.nextToken();
        if (token == VALUE_NULL)
            return null;

        while (true) {
            if (token == null)
                break;

            if (token == FIELD_NAME || token == START_OBJECT) {
                if (context.testExpression("Action", targetDepth)) {
                    context.nextToken();
                    sqlInjectionMatchSetUpdate.setAction(StringJsonUnmarshaller
                            .getInstance().unmarshall(context));
                }
                if (context.testExpression("SqlInjectionMatchTuple",
                        targetDepth)) {
                    context.nextToken();
                    sqlInjectionMatchSetUpdate
                            .setSqlInjectionMatchTuple(SqlInjectionMatchTupleJsonUnmarshaller
                                    .getInstance().unmarshall(context));
                }
            } else if (token == END_ARRAY || token == END_OBJECT) {
                if (context.getLastParsedParentElement() == null
                        || context.getLastParsedParentElement().equals(
                                currentParentElement)) {
                    if (context.getCurrentDepth() <= originalDepth)
                        break;
                }
            }
            token = context.nextToken();
        }

        return sqlInjectionMatchSetUpdate;
    }

    private static SqlInjectionMatchSetUpdateJsonUnmarshaller instance;

    public static SqlInjectionMatchSetUpdateJsonUnmarshaller getInstance() {
        if (instance == null)
            instance = new SqlInjectionMatchSetUpdateJsonUnmarshaller();
        return instance;
    }
}

==> aws-java-sdk-waf-1.11.29-sources.jar: com/amazonaws/services/waf/model/transform/SqlInjectionMatchSetUpdateJsonUnmarshaller.java <==
/*
 * Copyright 2011-2016 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"). You may not
 * use this file except in compliance with the License. A copy of the License is
 * located at
 * 
 * http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package com.amazonaws.services.waf.model.transform;

import java.util.Map;
import java.util.Map.Entry;
import java.math.*;
import java.nio.ByteBuffer;

import com.amazonaws.services.waf.model.*;
import com.amazonaws.transform.SimpleTypeJsonUnmarshallers.*;
import com.amazonaws.transform.*;

import com.fasterxml.jackson.core.JsonToken;
import static com.fasterxml.jackson.core.JsonToken.*;

/**
 * SqlInjectionMatchSetUpdate JSON Unmarshaller
 */
public class SqlInjectionMatchSetUpdateJsonUnmarshaller implements
        Unmarshaller<SqlInjectionMatchSetUpdate, JsonUnmarshallerContext> {

    public SqlInjectionMatchSetUpdate unmarshall(JsonUnmarshallerContext context)
            throws Exception {
        SqlInjectionMatchSetUpdate sqlInjectionMatchSetUpdate = new SqlInjectionMatchSetUpdate();

        int originalDepth = context.getCurrentDepth();
        String currentParentElement = context.getCurrentParentElement();
        int targetDepth = originalDepth + 1;

        JsonToken token = context.getCurrentToken();
        if (token == null)
            token = context.nextToken();
        if (token == VALUE_NULL)
            return null;

        while (true) {
            if (token == null)
                break;

            if (token == FIELD_NAME || token == START_OBJECT) {
                if (context.testExpression("Action", targetDepth)) {
                    context.nextToken();
                    sqlInjectionMatchSetUpdate.setAction(context
                            .getUnmarshaller(String.class).unmarshall(context));
                }
                if (context.testExpression("SqlInjectionMatchTuple",
                        targetDepth)) {
                    context.nextToken();
                    sqlInjectionMatchSetUpdate
                            .setSqlInjectionMatchTuple(SqlInjectionMatchTupleJsonUnmarshaller
                                    .getInstance().unmarshall(context));
                }
            } else if (token == END_ARRAY || token == END_OBJECT) {
                if (context.getLastParsedParentElement() == null
                        || context.getLastParsedParentElement().equals(
                                currentParentElement)) {
                    if (context.getCurrentDepth() <= originalDepth)
                        break;
                }
            }
            token = context.nextToken();
        }

        return sqlInjectionMatchSetUpdate;
    }

    private static SqlInjectionMatchSetUpdateJsonUnmarshaller instance;

    public static SqlInjectionMatchSetUpdateJsonUnmarshaller getInstance() {
        if (instance == null)
            instance = new SqlInjectionMatchSetUpdateJsonUnmarshaller();
        return instance;
    }
}
